==> jc-1.4.0.tar.gz: soot/jimple/parser/Parse.h <==
// public class soot.jimple.parser.Parse

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 93b64c99340fb1e8 soot_jimple_parser_Parse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_Parse_H_
#define _JC_soot_jimple_parser_Parse_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_Parse$sub_refs	_jc_soot_jimple_parser_Parse$sub_refs;
typedef struct _jc_soot_jimple_parser_Parse$sub_nonrefs	_jc_soot_jimple_parser_Parse$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_Parse$refs	_jc_soot_jimple_parser_Parse$refs;
typedef struct _jc_soot_jimple_parser_Parse$nonrefs	_jc_soot_jimple_parser_Parse$nonrefs;
typedef struct _jc_soot_jimple_parser_Parse$object	_jc_soot_jimple_parser_Parse$object;

typedef struct _jc_soot_jimple_parser_Parse$fields_struct	_jc_soot_jimple_parser_Parse$fields_struct;
typedef const struct _jc_soot_jimple_parser_Parse$vmethods	_jc_soot_jimple_parser_Parse$vmethods;
typedef const struct _jc_soot_jimple_parser_Parse$vtable	_jc_soot_jimple_parser_Parse$vtable;
typedef const struct _jc_soot_jimple_parser_Parse$vtype	_jc_soot_jimple_parser_Parse$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_Parse$fields_struct {
	struct _jc_java_lang_String$object	*EXT;
	struct _jc_java_lang_String$object	*USAGE;
};
extern _jc_soot_jimple_parser_Parse$fields_struct _jc_soot_jimple_parser_Parse$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_Parse$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_Parse$object *);

// Static methods
extern void _jc_soot_jimple_parser_Parse$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern struct _jc_soot_SootClass$object *_jc_soot_jimple_parser_Parse$method$parse$35f8024c06bf1039(_jc_env *, struct _jc_java_io_InputStream$object *, struct _jc_soot_SootClass$object *);

// Virtual methods structure
struct _jc_soot_jimple_parser_Parse$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_Parse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_Parse$vmethods	soot_jimple_parser_Parse;
};

// Vtype
struct _jc_soot_jimple_parser_Parse$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_Parse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_Parse$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_Parse$refs {
    _jc_soot_jimple_parser_Parse$sub_refs	soot_jimple_parser_Parse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_Parse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_Parse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_Parse$sub_nonrefs	soot_jimple_parser_Parse;
};

// Object instance structure
struct _jc_soot_jimple_parser_Parse$object {
	_jc_soot_jimple_parser_Parse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_Parse$vtype	*vtype;
	_jc_soot_jimple_parser_Parse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_Parse$vtype _jc_soot_jimple_parser_Parse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_Parse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_Parse$class_object;

#endif	/* _JC_soot_jimple_parser_Parse_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/Parse.h <==
// public class soot.jimple.parser.Parse

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 93b64c99340fb1e8 soot_jimple_parser_Parse

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_Parse_H_
#define _JC_soot_jimple_parser_Parse_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_SootClass$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_Parse$sub_refs	_jc_soot_jimple_parser_Parse$sub_refs;
typedef struct _jc_soot_jimple_parser_Parse$sub_nonrefs	_jc_soot_jimple_parser_Parse$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_Parse$refs	_jc_soot_jimple_parser_Parse$refs;
typedef struct _jc_soot_jimple_parser_Parse$nonrefs	_jc_soot_jimple_parser_Parse$nonrefs;
typedef struct _jc_soot_jimple_parser_Parse$object	_jc_soot_jimple_parser_Parse$object;

typedef struct _jc_soot_jimple_parser_Parse$fields_struct	_jc_soot_jimple_parser_Parse$fields_struct;
typedef const struct _jc_soot_jimple_parser_Parse$vmethods	_jc_soot_jimple_parser_Parse$vmethods;
typedef const struct _jc_soot_jimple_parser_Parse$vtable	_jc_soot_jimple_parser_Parse$vtable;
typedef const struct _jc_soot_jimple_parser_Parse$vtype	_jc_soot_jimple_parser_Parse$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_Parse$fields_struct {
	struct _jc_java_lang_String$object	*EXT;
	struct _jc_java_lang_String$object	*USAGE;
};
extern _jc_soot_jimple_parser_Parse$fields_struct _jc_soot_jimple_parser_Parse$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_Parse$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_Parse$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_soot_jimple_parser_Parse$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootClass$object *_jc_soot_jimple_parser_Parse$method$parse$35f8024c06bf1039(_jc_env *, struct _jc_java_io_InputStream$object *, struct _jc_soot_SootClass$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_Parse$vmethods {
};

// Vtable
struct _jc_soot_jimple_parser_Parse$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_Parse$vmethods	soot_jimple_parser_Parse;
};

// Vtype
struct _jc_soot_jimple_parser_Parse$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_Parse$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_Parse$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_Parse$refs {
    _jc_soot_jimple_parser_Parse$sub_refs	soot_jimple_parser_Parse;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_Parse$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_Parse$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_Parse$sub_nonrefs	soot_jimple_parser_Parse;
};

// Object instance structure
struct _jc_soot_jimple_parser_Parse$object {
	_jc_soot_jimple_parser_Parse$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_Parse$vtype	*vtype;
	_jc_soot_jimple_parser_Parse$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_Parse$vtype _jc_soot_jimple_parser_Parse$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_Parse, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_Parse$class_object;

#endif	/* _JC_soot_jimple_parser_Parse_H_ */
